#
# spec file for package lifelines
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lifelines
%global commit      3ad4571
%global longcommit  3ad457132c47fde69545d6647d5804c573764631
Version:        3.1.1+%{commit}
Release:        bp153.2.1
Summary:        The Lifelines Genealogy Program
License:        MIT
Group:          Productivity/Scientific/Other
URL:            https://github.com/lifelines/lifelines
Source0:        https://github.com/%{name}/%{name}/archive/%{commit}.tar.gz#/%{name}-%{commit}.tar.gz
Source1:        %{name}-rpmlintrc
# PATCH-FIX-SUSE mainly to get paths correct if installed as system package
Patch0:         lifelines-%{commit}.dif
# PATCH-FIX-SUSE avoid memory leak as well as no initialized array
Patch1:         lifelines-%{commit}-array.dif
# PATCH-FIX-UPSTREAM https://github.com/lifelines/lifelines/pull/389
Patch2:         reproducible.patch
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  dblatex
BuildRequires:  docbook-utils
BuildRequires:  dos2unix
BuildRequires:  libjpeg-devel
BuildRequires:  libpng
BuildRequires:  libxslt-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl-XML-DOM
BuildRequires:  perl-XML-Parser
BuildRequires:  perl-XML-SAX
BuildRequires:  perl-libwww-perl
BuildRequires:  texlive
BuildRequires:  texlive-babel
BuildRequires:  texlive-babel-swedish
BuildRequires:  texlive-cmap
BuildRequires:  texlive-courier
BuildRequires:  texlive-dvips
BuildRequires:  texlive-ec
BuildRequires:  texlive-fancybox
BuildRequires:  texlive-helvetic
BuildRequires:  texlive-jadetex
BuildRequires:  texlive-jknapltx
BuildRequires:  texlive-latex
BuildRequires:  texlive-times
BuildRequires:  texlive-xmltex
BuildRequires:  tidy
BuildRequires:  w3m
BuildRequires:  xmlto
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Lifelines is terminal-based program that allows the tracking of
genealogical information.  The lifelines reports are the power of the
system but requires knowledge in the ll format.

%prep
%setup -q -c -T -n %{name}-%{commit}
tar -x  --strip-components=1 -z -f %{SOURCE0} 
%patch0 -p0 -b .p0
%patch1 -p0 -b .p1
%patch2 -p1 -b .p2

%build
if test $(getconf LONG_BIT) -gt 32
then
    arch=--with-64bit
else
    arch=--with-32bit
fi
CFLAGS="%{optflags} -fno-strict-aliasing -pipe $(pkg-config ncursesw --cflags) $(getconf LFS_CFLAGS)"
CPPFLAGS="-D_GNU_SOURCE -D_XOPEN_CURSES"
LIBS="$(pkg-config ncursesw --libs)"
CC=gcc
export CC CFLAGS CPPFLAGS LIBS
autoreconf -fi
%ifarch aarch64 %arm
# gcc on aarch64 does not know about -m64 ...
sed -ri 's/[[:space:]]*-m(64|32)//' configure
%endif
%configure  --disable-rpath			\
	    --with-gnu-ld			\
	    --with-docs				\
	    $arch				\
	    --with-libintl-prefix=%{_prefix}
make %{?_smp_mflags}
make -C docs/
dos2unix lines.cfg

%install
make DESTDIR=%{buildroot}		\
     docdir=%{_defaultdocdir}/%{name}	\
     pkgdatadir=%{_datadir}/%{name}	\
     install
make -C docs/ DESTDIR=%{buildroot}	\
     docdir=%{_defaultdocdir}/%{name}	\
     pkgdatadir=%{_datadir}/%{name}	\
     install
%find_lang %{name}
rm -vf %{buildroot}%{_defaultdocdir}/%{name}/INSTALL
mkdir -p %{buildroot}%{_sysconfdir}/skel
mv %{buildroot}%{_defaultdocdir}/%{name}/.linesrc \
   %{buildroot}%{_sysconfdir}/skel/
chmod 755 %{buildroot}%{_datadir}/%{name}/gen_index
rm -vf %{buildroot}%{_datadir}/%{name}/desc-tex2/tree.tex
rm -vf %{buildroot}%{_datadir}/%{name}/pedtex/tree.tex
ln -sf ../tree.tex %{buildroot}%{_datadir}/%{name}/desc-tex2/tree.tex
ln -sf ../tree.tex %{buildroot}%{_datadir}/%{name}/pedtex/tree.tex

%files -f %{name}.lang
%defattr(-,root,root)
%config %{_sysconfdir}/skel/.linesrc
%doc %{_defaultdocdir}/%{name}
%{_bindir}/*
%{_datadir}/%{name}
%doc %{_mandir}/man1/*.gz

%changelog
* Tue Jun  9 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Tue Apr  7 2020 Dr. Werner Fink <werner@suse.de>
- Avoid -m64 on aarch64 (and also -m32 on arm) as gcc does not know about
* Fri Aug 23 2019 Dr. Werner Fink <werner@suse.de>
- Switch from LDFLAGS to LIBS to let configure find has_key() in libtinfo
* Fri Aug 23 2019 Dr. Werner Fink <werner@suse.de>
- Update to lifelines git version 3ad4571, which is the follower
  of lifelines version 3.1.1 (bug boo#1146704)
  * Removep patches
    lifelines-3.0.59-funcptr.dif now upstream solved
    lifelines-decl.patch now superfluous
  * Port patches
    lifelines-3.0.60-array.dif which becomes lifelines-3ad4571-array.dif
    lifelines-3.0.62.dif which becomes lifelines-3ad4571.dif
* Mon Feb  6 2017 dimstar@opensuse.org
- Favor newer ncurses versions over older ones (e.g.
  ncurses6-config > ncurses5-config).
* Tue Oct  6 2015 werner@suse.de
- Make it build with latest ncurses
* Mon Feb 24 2014 schwab@suse.de
- lifelines-decl.patch: fix conflicting declaration
* Wed Apr  3 2013 joop.boonen@opensuse.org
- Cleaned the spec file up
* Tue Jul 24 2012 werner@suse.de
- Add missing font
* Tue Jul 10 2012 werner@suse.de
- Make it build with latest TeXLive 2012 with new package layout
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Jul  8 2009 coolo@novell.com
- fix build with automake 1.11
* Mon May  5 2008 werner@suse.de
- Reqiures also xmltex
* Thu Apr 10 2008 werner@suse.de
- Changes for new ncurses header location
* Tue Mar 25 2008 werner@suse.de
- Work around missing LaTeX format for JadeTeX
* Fri Dec 14 2007 werner@suse.de
- Update to lifelines 3.0.62
  * Fix encoding conversion for GEDCOM, pedigree, and GEDCOM modes
  * Improved German translation
  * Improvements to configure finding curses
  * More strings made ready for internationalization
  * Minor doc tweaks, and packaging tweaks for Debian
* Wed Aug  1 2007 werner@suse.de
- Update to lifelines 3.0.60: Fixes a lot of documentation
- Avoid broken brp-symlink check
- Avoid some RPMlint warnings
* Thu Jun 21 2007 werner@suse.de
- Update to lifelines 3.0.59: Is able to handle UTF-8
* Sun Apr 22 2007 ro@suse.de
- use texlive for building
* Fri Mar 30 2007 rguenther@suse.de
- Add bison and ncurses-devel BuildRequires.
* Sat Oct 21 2006 schwab@suse.de
- Properly use autoreconf.
* Thu Jun 22 2006 ro@suse.de
- remove selfprovides
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 werner@suse.de
- Fix array subscript number (bug #144800)
* Fri Sep 30 2005 werner@suse.de
- Update to lifelines 3.0.46.1 to get it work even with ncurses 5.4
* Thu Sep 29 2005 werner@suse.de
- Re-enable traditional address handling (-fno-strict-aliasing)
* Wed Jun 22 2005 ke@suse.de
- Add docbook-dsssl-stylesheets to neededforbuild and enable building
  docs.
* Tue Jun 14 2005 werner@suse.de
- New package: lifelines, a genealogy program
